﻿""" Addon Information """
# ------------
# EventScripts Script-Addon:    Autokick (autokick.py, 6.3kb)
# Author:                       BackRaw - http://forums.eventscripts.com/profile.php?mode=viewprofile&u=13683
#                                         http://addons.eventscripts.com/addons/user/13683
# Version:                      1.1
# ------------

""" Imports """
# ------------
# EventScripts Core-Module            - ES functionality
import es
# cPickle                             - Database File:      ./addons/eventscripts/autokick/autokicked.db
import cPickle
# OS.Path                             - Check file existence
from os.path import isfile
# Gamethread                          - Delayed functions
from gamethread import delayed
# Usermsg                             - "Echo" the client console without any issues
from usermsg import echo
# Config Object                       - Configuration File: ./addons/eventscripts/autokick_config.ini
from configobj import ConfigObj
# ------------

""" Config Wrapper """
# ------------
# This wrapper handles the configuration file
# ------------
def config(name, section=False):
    f = ConfigObj(es.getAddonPath('autokick') + '/autokick_config.ini')
    if section:
        return f[section][name]
    return f[name]

""" Classes - DB """
# ------------
# The Database-Class
# This class saves and loads the database file.
# ------------
class DB(object):
    def __init__(self):
        self.file = es.getAddonPath('autokick') + '/autokicked.db'
    def loadDatabase(self):
        if isfile(self.file):
            f = open(self.file, 'rb')
            db = cPickle.load(f)
            f.close()
            return db
        return {}
    def saveDatabase(self):
        f = open(self.file, 'wb')
        cPickle.dump(player, f)
        f.close()
db = DB()

""" Classes - autokick """
# ------------
# This class handles autokicking of players.
# ------------
class autokick:
    def __init__(self, steam):
        self.steam = steam
        self.name = self.reason = 0
    def kickSteam(self):
        es.server.queuecmd('kickid %s "%s"' % (es.getuserid(self.steam), self.reason))
    def addSteam(self, reason=''):
        self.reason = reason
        self.kickSteam()
        db.saveDatabase()

""" Events """
# ------------
# On player_activate, check if the player was added to the database, if so, kick them immedietly.
# ------------
def player_activate(ev):
    steam = ev['es_steamid']
    if steam in player:
        if steam != 'BOT':
            delayed(1, player[steam].kickSteam)
        else:
            es.delayed(1, 'bot_kick %s' % ev['es_username'])

""" Say-Filter """
# ------------
# This say-filter handles autokicking and un-autokicking along with listing the autokicked players.
# A filter is much better for on-the-fly configuration.
# Now - as soon as configuration settings are changed, they will be recognized immedietly.
# ------------
def sayFilter(userid, text, teamonly):
    listkicked = config('listkicked', 'saycommands')
    autokickcmd = config('autokick', 'saycommands')
    unautokickcmd = config('unautokick', 'saycommands')
    text = text.strip('"')
    args = text.split(' ')
    if args[0] in [listkicked, autokickcmd, unautokickcmd]:
        prefix = '#green[#lightgreenAuto Kick#green]'
        steam = es.getplayersteamid(userid)
        if steam in config('admins'):
            if listkicked in text:
                es.cexec(userid, 'echo ----------------------------------')
                es.cexec(userid, 'echo ')
                es.cexec(userid, 'echo Listing Auto-Kicked players...')
                es.cexec(userid, 'echo ')
                es.cexec(userid, 'echo SteamID -- Name -- Reason')
                es.cexec(userid, 'echo ------------------------')
                es.cexec(userid, 'echo ')
                for steam in player:
                    es.cexec(userid, 'echo %s -- %s -- %s\n' % (str(steam), player[steam].name, player[steam].reason))
                es.cexec(userid, 'echo ')
                es.cexec(userid, 'echo ----------------------------------')
            elif autokickcmd in text:
                if len(args) >= 2:
                    target = args[1]
                    steam = 0
                    if not target.startswith('STEAM_'):
                        steam = str(es.getplayersteamid(target)).upper()
                    else:
                        steam = target
                    target = es.getuserid(steam)
                    if steam not in player:
                        player[steam] = autokick(steam)
                        player[steam].name = es.getplayername(target)
                        player[steam].addSteam(text[len(autokickcmd) + len(args[1]) + 2:])
                        db.saveDatabase()
                        es.tell(userid, '#multi', prefix, '#defaultAdded #lightgreen%s #defaultto the Database.' % steam)
                    else:
                        es.tell(userid, '#multi', prefix, '#lightgreen%s #defaultis already saved in the Database.' % steam)
                else:
                    es.tell(userid, '#multi', prefix, '#defaultWrong Syntax: !autokick <name> <reason>')
            elif unautokickcmd in text:
                steam = args[1].upper()
                if steam in player:
                    del player[steam]
                    db.saveDatabase()
                    es.tell(userid, '#multi', prefix, '#defaultRemoved #lightgreen%s #defaultfrom Database.' % steam)
                else:
                    es.tell(userid, '#multi', prefix, "#lightgreen%s #defaultisn't saved in the Database." % steam)
                    es.tell(userid, '#multi', prefix, '#defaultType #lightgreen%s #defaultin the chat and look up your console for saved SteamIDs.' % listkicked)
        else:
            es.tell(userid, '#multi', prefix, '#lightgreen%s #defaultis no Admin.' % steam)
        return (None, None, None)
    return (userid, text, teamonly)

""" EventScripts Main-Control functions """
# ------------
# On load, load the database and register the say-filter
# ------------
def load():
    global player
    es.ServerVar('autokick_ver', '1.1').makepublic()
    player = db.loadDatabase()
    es.addons.registerSayFilter(sayFilter)

# ------------
# On unload, save the database and un-register the say-filter
# ------------
def unload():
    db.saveDatabase()
    es.addons.unregisterSayFilter(sayFilter)

""" End Code """
